Method: CfYAML.load
- Defined in:
- lib/libcfruby/cfyaml.rb
.load(filename, changed = false) ⇒ Object
Executes a YAML file by loading it and processing each array entry in it in turn recursively, depth first. changed is only used internally.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/libcfruby/cfyaml.rb', line 50 def CfYAML.load(filename, changed=false) fp = filename if(!filename.kind_of?(IO)) fp = File.open(filename, File::RDONLY) end cfyamlcode = YAML.load(fp) return(process(cfyamlcode, changed)) end |